/* Copyright (c) 2015 - 2017, Nordic Semiconductor ASA
 *
 * All rights reserved.
 *
 * Use in source and binary forms, redistribution in binary form only, with
 * or without modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions in binary form, except as embedded into a Nordic
 *    Semiconductor ASA integrated circuit in a product or a software update for
 *    such product, must reproduce the above copyright notice, this list of
 *    conditions and the following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 *
 * 2. Neither the name of Nordic Semiconductor ASA nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * 3. This software, with or without modification, must only be used with a Nordic
 *    Semiconductor ASA integrated circuit.
 *
 * 4. Any software provided in binary form under this license must not be reverse
 *    engineered, decompiled, modified and/or disassembled.
 *
 * THIS SOFTWARE IS PROVIDED BY NORDIC SEMICONDUCTOR ASA "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL NORDIC SEMICONDUCTOR ASA OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

'use strict';

import _ from 'lodash';
import React from 'react';
import PropTypes from 'prop-types';

class AddNewItem extends React.PureComponent {
    componentWillReceiveProps(nextProps) {
        // if we're selected through keyboard navigation, we need to make sure we're visible

        const selectedId = nextProps.selected;
        if (nextProps.id === selectedId && nextProps.onRequestVisibility) {
            nextProps.onRequestVisibility();
        }

        // open bug: https://github.com/yannickcr/eslint-plugin-react/issues/944
        const { id, selected, onRequestVisibility } = this.props; // eslint-disable-line
    }

    render() {
        const { bars: propBars, onClick, text } = this.props;
        const bars = _.times(propBars, i => <div className={`bar${i + 1}`} key={i} />);

        return (
            <div
                className="add-new"
                onClick={onClick}
                onKeyDown={onClick}
                role="button"
                tabIndex={0}
            >
                {bars}
                <div className="content-wrap">
                    <div className="content padded-row">
                        <span className="icon-wrap">
                            <i className="icon-slim mdi mdi-plus-circle" />
                        </span>
                        <span>{text}</span>
                    </div>
                </div>
            </div>
        );
    }
}

AddNewItem.propTypes = {
    id: PropTypes.string.isRequired,
    bars: PropTypes.number.isRequired,
    selected: PropTypes.string,
    text: PropTypes.string.isRequired,
    onClick: PropTypes.func.isRequired,
    onRequestVisibility: PropTypes.func,
};

AddNewItem.defaultProps = {
    selected: null,
    onRequestVisibility: null,
};

export default AddNewItem;
